@@ -124,6 +124,7 @@ dist.lite = function(x, y){
 #' point and all others in a given set, for every point.
 #' @param x data.frame. With two columns containing latitude and longitude, describing
 #' the predicted locations of a species, which may contain outliers.
+#' @param na.rm logical. If \code{TRUE} check first for columns completely missing from the data and remove them.
 #' @details Euclidean distance calculated is given by:
 #' \eqn{d(p,q) =  \sqrt{\sum_{i=1}^{n}(q_i - p_i)²}},
 #' with \eqn{p}, \eqn{q} being two points in Euclidean space, creating vectors 
@@ -133,8 +134,40 @@ dist.lite = function(x, y){
 #' gecko:::dist.euclid(occurence)
 #' @return numeric.
 #' @noRd
-dist.euclid = function(x, threshold = 0.05){
-  na_rows <- c(1:nrow(x))[rowSums(is.na(x[, 1:ncol(x)])) > 0]
+dist.euclid = function(x, threshold = 0.05, na.rm = TRUE){
+  x = as.data.frame(x)
+  for (j in 1:ncol(x)){
+    x[is.nan(x[,j]),j] = NA
+  }
+  
+  if (!na.rm){
+    na_rows <- c(1:nrow(x))[rowSums(is.na(x[, 1:ncol(x)])) > 0]
+  } else {
+    dims_removed = c(1:ncol(x))[as.logical(colSums(is.na(x[,1:ncol(x)])) > 0)]
+    if (length(dims_removed) == 0){
+      na_rows = c()
+    } else {
+      if (length(dims_removed) == ncol(x)){
+        message("All dimensions are missing at least one value. Trying rows.")
+        
+        na_rows <- c(1:nrow(x))[rowSums(is.na(x[, 1:ncol(x)])) > 0]
+      } else {
+        message(
+          paste0(
+            "Dimensions (", paste0(dims_removed, collapse = ", "), ") are missing at least one value. Removing and proceeding."
+          )
+        )
+        x = x[,-dims_removed]
+        na_rows = c()
+      }
+    }
+    
+    
+    
+
+  }
+  
+  
   x <- apply(x, 2, FUN = as.double)
   x <- as.data.frame(x)
   
@@ -159,3 +192,4 @@ dist.euclid = function(x, threshold = 0.05){
   qvalue <- quantile(means, 0.95, na.rm = TRUE)
   return(means >= qvalue)
 }
+
